﻿using DotNetCore.CAP;
using Hotline.Share.Dtos.Order;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Mvc;
using Sharing.Application;
using Sharing.Notifications;
using Sharing.Orders;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;
using Sharing.Repository.Province.XieTong.Send;
using Sharing.WebCore;
using System.Threading;

namespace Sharing.Api.Controllers
{
    /// <summary>
    /// 
    /// </summary>
    public class HotlineMessageReceiveController : Controller
    {
        private readonly IDataOrderRepository _dataOrderRepository;
        private readonly IMediator _mediator;
        private readonly ILogger<HotlineMsgReceiver> _logger;
        private readonly IMapper _mapper;
        private readonly IGetCaseResultReceiveRepository _getCaseResultReceiveRepository;
        private readonly IGetCaseProcessReceiveRepository _getCaseProcessReceiveRepository;
        private readonly IGetVisitInfoReceiveRepository _getVisitInfoReceiveRepository;
        private readonly IGetCaseBackApplyRepository _getCaseBackApplyRepository;
        private readonly IDelayCaseInfoSendRepository _delayCaseInfoSendRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="dataOrderRepository"></param>
        /// <param name="mediator"></param>
        /// <param name="logger"></param>
        /// <param name="mapper"></param>
        /// <param name="getCaseResultReceiveRepository"></param>
        public HotlineMessageReceiveController(IDataOrderRepository dataOrderRepository, IMediator mediator, ILogger<HotlineMsgReceiver> logger, IMapper mapper
            , IGetCaseResultReceiveRepository getCaseResultReceiveRepository, IGetCaseProcessReceiveRepository getCaseProcessReceiveRepository
            , IGetVisitInfoReceiveRepository getVisitInfoReceiveRepository, IGetCaseBackApplyRepository getCaseBackApplyRepository
            , IDelayCaseInfoSendRepository delayCaseInfoSendRepository)
        {
            _dataOrderRepository = dataOrderRepository;
            _mediator = mediator;
            _logger = logger;
            _mapper = mapper;
            _getCaseResultReceiveRepository = getCaseResultReceiveRepository;
            _getCaseProcessReceiveRepository = getCaseProcessReceiveRepository;
            _getVisitInfoReceiveRepository = getVisitInfoReceiveRepository;
            _getCaseBackApplyRepository = getCaseBackApplyRepository;
            _delayCaseInfoSendRepository = delayCaseInfoSendRepository;
        }

        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task ReceiveOrderCreated(OrderDto dto)
        {
            // //todo receive mq msg, write into db, publish inprocess msg
            // _logger.LogInformation("rec order");
            // await _dataOrderRepository.AddAsync(new DataOrder(), HttpContext.RequestAborted);

             await _mediator.Publish(new OrderCreatedNotification(new DataOrder()));
            // _logger.LogInformation("publish order success!");
        }

        /// <summary>
        /// 服务工单交办处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task GetCaseResultReceive(GetCaseResultReceiveInfo dto)
        {
            var data = _mapper.Map<GetCaseResultReceive>(dto);

            //将上报信息写入本地库
            var id= await _getCaseResultReceiveRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetCaseResultReceiveNotification(data));

        }

        /// <summary>
        /// 服务工单交办处理过程  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task GetCaseProcessReceive(GetCaseProcessReceiveInfo dto)
        {
            var data = _mapper.Map<GetCaseProcessReceive>(dto);

            //将上报信息写入本地库
            var id = await _getCaseProcessReceiveRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetCaseProcessReceiveNotification(data));
        }

        /// <summary>
        /// 服务工单交办评价  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task GetVisitInfoReceive(GetVisitInfoReceiveInfo dto)
        {
            var data = _mapper.Map<GetVisitInfoReceive>(dto);

            //将上报信息写入本地库
            var id = await _getVisitInfoReceiveRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetVisitInfoReceiveNotification(data));
        }

        /// <summary>
        /// 退回申请  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task GetCaseBackApply(GetCaseBackApplyInfo dto)
        {
            var data = _mapper.Map<GetCaseBackApply>(dto);

            //将上报信息写入本地库
            var id = await _getCaseBackApplyRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetCaseBackApplyNotification(data));
        }

        /// <summary>
        /// 服务工单申请延时  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task DelayCaseInfoSend(DelayCaseInfoSendInfo dto)
        {
            var data = _mapper.Map<DelayCaseInfoSend>(dto);

            //将上报信息写入本地库
            var id = await _delayCaseInfoSendRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new DelayCaseInfoSendNotification(data));
        }
    }
}
