﻿using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu;
using Sharing.Province.Dtos.XieTong.Send;

namespace Sharing.Province;

/// <summary>
/// 默认策略（保持原数据策略）
/// </summary>
public class DefaultPusher : IProvincePusher
{
    private readonly HuiJuClient _huiJuClient;
    private readonly XieTongClient _xieTongClient;

    /// <summary>
    /// 
    /// </summary>
    /// <param name="huiJuClient"></param>
    /// <param name="xieTongClient"></param>
    public DefaultPusher(HuiJuClient huiJuClient, XieTongClient xieTongClient)
    {
        _huiJuClient = huiJuClient;
        _xieTongClient = xieTongClient;
    }

    public async Task PushOrderCreatedAsync(SubmitCaseInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseInfoRequest, ProvinceResponse>(request, cancellationToken);
    }

    /// <summary>
    /// 服务工单交办处理
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetCaseResultReceiveAsync(GetCaseResultReceiveRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetCaseResultReceiveRequest, ProvinceResponse>(request, cancellationToken);
        return response.ReturnInfo;
    }

    /// <summary>
    /// 服务工单交办处理过程
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetCaseProcessReceiveAsync(GetCaseProcessReceiveRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetCaseProcessReceiveRequest, ProvinceResponse>(request, cancellationToken);
        return response.ReturnInfo;
    }

    /// <summary>
    /// 服务工单交办评价
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetVisitInfoReceiveAsync(GetVisitInfoReceiveRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetVisitInfoReceiveRequest, ProvinceResponse>(request, cancellationToken);
        return response.ReturnInfo;
    }

    /// <summary>
    /// 退回申请
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetCaseBackApplyAsync(GetCaseBackApplyRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetCaseBackApplyRequest, ProvinceResponse>(request, cancellationToken);
        return response.ReturnInfo;
    }

    /// <summary>
    /// 服务工单申请延时
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushDelayCaseInfoSendAsync(DelayCaseInfoSendRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<DelayCaseInfoSendRequest, ProvinceResponse>(request, cancellationToken);
        return response.ReturnInfo;
    }
}