﻿using Microsoft.AspNetCore.Http;
using System.Text.Json.Serialization;

namespace Sharing.Province.Dtos.HuiJu;

public class SubmitCaseInfoRequest : ProvinceRequest<SubmitCaseInfoData>
{
    //业务汇聚-服务工单受理接口

    public override string GetRequestUrl() => "submit_case_info";

    public override string GetHttpMethod() => HttpMethods.Post;
}

public class SubmitCaseInfoData
{
    [JsonPropertyName("jsonList")]
    public IReadOnlyList<CaseInfo> CaseInfos { get; set; }
}

public class CaseInfo
{
    /*
     * "CASE_SERIAL":"服务工单编号",
"CASE_TITLE":"服务工单标题",
"CASE_REGISTER":"服务代表姓名",
"CASE_REGISTERNO":"服务代表工号",
"CASE_DATE":"登记时间",
"CASE_SOURCE":"诉求渠道",
"PHONE_NUMBER":"联系电话",
"APPLICANT_NAME":"服务对象名称",
"APPLICANT_SEX":"服务对象性别",
"APPLICANT_AGE":"服务对象年龄",
"APPLICANT_ID":"证件号码",
"CERTIFICATE_TYPE":"证件类型",
"CASE_TYPE":"诉求类型",
"CASE_ACCORD":"诉求归口",
"CASE_CONTENT":"诉求内容",
"CASE_PROCESS_TYPE":"处理方式",
"CASE_ISPUBLIC":"是否公开",
"CASE_ISSECRECT":"是否保密",
"CASE_ISVISIT":"是否回访",
"CASE_VALID":"是否有效受理"，
"CASE_ISURGENT":"紧急程度",
 "TSIGNTIME_BF":"应签收时限",
"TFDBACKTIME_BF":"应办结时限",
"TBACKTIME_BF":"应退回时限",
 "RELATE_SERIAL":"关联服务工单",
"AREA_CODE":"行政区划代码",
"CASE_LNGLAT":"经纬度",
"CASE_EMOTION":"诉求情感",
 "CASE_ADDRESS":"诉求详细地址",
"EVENT_DATE":"事发时间",
"CASE_GOAL":"诉求目的",
"THEME_SERIAL":"主题工单类型",
"CLIENG_GUID":"材料标识",
"ADVISE_TYPE":"建议类型",
"ADVISE_DEPT":"建议部门",
"COMPLAIN_TYPE":"投诉类型",
"COMPLAIN_DEPT":"投诉部门"
"PUSH_TYPE":"推送类型"
     */

    /// <summary>
    /// 服务工单编号
    /// </summary>
    [JsonPropertyName("CASE_SERIAL")]
    public string OrderNo { get; set; }

    /// <summary>
    /// 服务工单标题
    /// </summary>
    [JsonPropertyName("CASE_TITLE")]
    public string OrderTitle { get; set; }

    /// <summary>
    /// 服务代表姓名
    /// </summary>
    [JsonPropertyName("CASE_REGISTER")]
    public string EmployeeId { get; set; }

    /// <summary>
    /// 服务代表工号
    /// </summary>
    [JsonPropertyName("CASE_REGISTERNO")]
    public string EmployeeStaffNo { get; set; }

    /// <summary>
    /// 登记时间
    /// </summary>
    [JsonPropertyName("CASE_DATE")]
    public DateTime CreationTime { get; set; }

    /// <summary>
    /// 诉求渠道
    /// </summary>
    [JsonPropertyName("CASE_SOURCE")]
    public DateTime Channel { get; set; }

    /// <summary>
    /// 联系电话
    /// </summary>
    [JsonPropertyName("PHONE_NUMBER")]
    public string FromPhone { get; set; }

    /// <summary>
    /// 服务对象名称
    /// </summary>
    [JsonPropertyName("APPLICANT_NAME")]
    public string FromName { get; set; }

    /// <summary>
    /// 服务对象性别
    /// </summary>
    [JsonPropertyName("APPLICANT_SEX")]
    public string FromGender { get; set; }

    /// <summary>
    /// 服务对象年龄
    /// </summary>
    [JsonPropertyName("APPLICANT_AGE")]
    public string FromAge { get; set; }

    /// <summary>
    /// 证件号码
    /// </summary>
    [JsonPropertyName("APPLICANT_ID")]
    public string LicenceNo { get; set; }

    /// <summary>
    /// 证件类型
    /// </summary>
    [JsonPropertyName("CERTIFICATE_TYPE")]
    public string LicenceTypeCode { get; set; }

    /// <summary>
    /// 诉求类型
    /// </summary>
    [JsonPropertyName("CASE_TYPE")]
    public string AcceptType { get; set; }

    /// <summary>
    /// 诉求归口
    /// </summary>
    [JsonPropertyName("CASE_ACCORD")]
    public string Hotspot { get; set; }

    /// <summary>
    /// 诉求内容
    /// </summary>
    [JsonPropertyName("CASE_CONTENT")]
    public string Content { get; set; }

    /// <summary>
    /// 处理方式
    /// </summary>
    [JsonPropertyName("CASE_PROCESS_TYPE")]
    public string ProcessType { get; set; }

    /// <summary>
    /// 是否公开
    /// </summary>
    [JsonPropertyName("CASE_ISPUBLIC")]
    public string IsPublic { get; set; }

    /// <summary>
    /// 是否保密
    /// </summary>
    [JsonPropertyName("CASE_ISSECRECT")]
    public string IsSecrect { get; set; }

    /// <summary>
    /// 是否回访-工单是否需要回访
    /// </summary>
    [JsonPropertyName("CASE_ISVISIT")]
    public string NeedContact { get; set; }

    /// <summary>
    /// 是否有效受理
    /// </summary>
    [JsonPropertyName("CASE_VALID")]
    public string Valid { get; set; }

    /// <summary>
    /// 紧急程度
    /// </summary>
    [JsonPropertyName("CASE_ISURGENT")]
    public string EmergencyLevel { get; set; }

    /// <summary>
    /// 应签收时限
    /// </summary>
    [JsonPropertyName("TSIGNTIME_BF")]
    public DateTime? SignTime { get; set; }

    /// <summary>
    /// 应办结时限
    /// </summary>
    [JsonPropertyName("TFDBACKTIME_BF")]
    public DateTime? CompleteTime { get; set; }

    /// <summary>
    /// 应退回时限
    /// </summary>
    [JsonPropertyName("TBACKTIME_BF")]
    public DateTime? ReturnTime { get; set; }

    /// <summary>
    /// 关联服务工单
    /// </summary>
    [JsonPropertyName("RELATE_SERIAL")]
    public string? DuplicateId { get; set; }

    /// <summary>
    /// 行政区划代码
    /// </summary>
    [JsonPropertyName("AREA_CODE")]
    public string AreaCode { get; set; }

    /// <summary>
    /// 经纬度
    /// </summary>
    [JsonPropertyName("CASE_LNGLAT")]
    public string Lnglat { get; set; }

    /// <summary>
    /// 诉求情感
    /// </summary>
    [JsonPropertyName("CASE_EMOTION")]
    public string Emotion { get; set; }

    /// <summary>
    /// 诉求详细地址
    /// </summary>
    [JsonPropertyName("CASE_ADDRESS")]
    public string Address { get; set; }

    /// <summary>
    /// 事发时间
    /// </summary>
    [JsonPropertyName("EVENT_DATE")]
    public DateTime? IncidentTime { get; set; }

    /// <summary>
    /// 诉求目的
    /// </summary>
    [JsonPropertyName("CASE_GOAL")]
    public string Goal { get; set; }

    /// <summary>
    /// 主题工单类型
    /// </summary>
    [JsonPropertyName("THEME_SERIAL")]
    public string Serial { get; set; }

    /// <summary>
    /// 材料标识
    /// </summary>
    [JsonPropertyName("CLIENG_GUID")]
    public string CliengId { get; set; }

    /// <summary>
    /// 建议类型
    /// </summary>
    [JsonPropertyName("ADVISE_TYPE")]
    public string AdviseType { get; set; }

    /// <summary>
    /// 建议部门
    /// </summary>
    [JsonPropertyName("ADVISE_DEPT")]
    public string AdviseDept { get; set; }

    /// <summary>
    /// 投诉类型
    /// </summary>
    [JsonPropertyName("COMPLAIN_TYPE")]
    public string ComplainType { get; set; }

    /// <summary>
    /// 投诉部门
    /// </summary>
    [JsonPropertyName("COMPLAIN_DEPT")]
    public string ComplainDept { get; set; }

    /// <summary>
    /// 推送类型
    /// </summary>
    [JsonPropertyName("PUSH_TYPE")]
    public string PushType { get; set; }
}
