﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers
{
    /// <summary>
    /// 退回申请
    /// </summary>
    public class GetCaseBackApplyHandler : INotificationHandler<GetCaseBackApplyNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IGetCaseBackApplyRepository _getCaseBackApplyRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="getCaseBackApplyRepository"></param>
        public GetCaseBackApplyHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IGetCaseBackApplyRepository getCaseBackApplyRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _getCaseBackApplyRepository = getCaseBackApplyRepository;
        }

        /// <summary>
        /// 退回申请
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetCaseBackApplyNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<GetCaseBackApplyInfo>(notification.Data);
            var data = new GetCaseBackApplyData
            {
                GetCaseBackApplyInfos = new List<GetCaseBackApplyInfo>
                {
                    dataReceive
                }
            };

            var request = new GetCaseBackApplyRequest();
            request.SetData(data);

            var response = await pusher.PushGetCaseBackApplyAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null && response.Code == "1")
            {
                notification.Data.SyncState = "1";
                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _getCaseBackApplyRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
