﻿using MediatR;
using Sharing.Notifications;
using Sharing.Province.Dtos.HuiJu;

namespace Sharing.Province.Handlers
{
    public class OrderCreatedHandler : INotificationHandler<OrderCreatedNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;

        public OrderCreatedHandler(
            IChannelConfigurationManager channelConfigurationManager,
            PusherProvider pusherProvider)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(OrderCreatedNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var data = new SubmitCaseInfoData
            {
                CaseInfos = new List<CaseInfo>
                {
                    new CaseInfo
                    {
                        OrderNo = order.OrderNo,
                        OrderTitle = order.OrderId
                    }
                }
            };
            var request = new SubmitCaseInfoRequest();
            request.SetData(data);

            await pusher.PushOrderCreatedAsync(request, cancellationToken);
        }
    }
}